==> aliyun_python_sdk_dataworks_public-3.4.9-py2.py3-none-any.whl: aliyunsdkdataworks_public/request/v20200518/CreateExportMigrationRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class CreateExportMigrationRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'CreateExportMigration')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_ExportObjectStatus(self):
		return self.get_body_params().get('ExportObjectStatus')

	def set_ExportObjectStatus(self,ExportObjectStatus):
		self.add_body_params('ExportObjectStatus', ExportObjectStatus)

	def get_ExportMode(self):
		return self.get_body_params().get('ExportMode')

	def set_ExportMode(self,ExportMode):
		self.add_body_params('ExportMode', ExportMode)

	def get_IncrementalSince(self):
		return self.get_body_params().get('IncrementalSince')

	def set_IncrementalSince(self,IncrementalSince):
		self.add_body_params('IncrementalSince', IncrementalSince)

	def get_Name(self):
		return self.get_body_params().get('Name')

	def set_Name(self,Name):
		self.add_body_params('Name', Name)

	def get_Description(self):
		return self.get_body_params().get('Description')

	def set_Description(self,Description):
		self.add_body_params('Description', Description)

	def get_ProjectId(self):
		return self.get_body_params().get('ProjectId')

	def set_ProjectId(self,ProjectId):
		self.add_body_params('ProjectId', ProjectId)

==> aliyun_python_sdk_dataworks_public-3.4.16-py2.py3-none-any.whl: aliyunsdkdataworks_public/request/v20200518/CreateExportMigrationRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class CreateExportMigrationRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'CreateExportMigration')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_ExportObjectStatus(self): # String
		return self.get_body_params().get('ExportObjectStatus')

	def set_ExportObjectStatus(self, ExportObjectStatus):  # String
		self.add_body_params('ExportObjectStatus', ExportObjectStatus)
	def get_ExportMode(self): # String
		return self.get_body_params().get('ExportMode')

	def set_ExportMode(self, ExportMode):  # String
		self.add_body_params('ExportMode', ExportMode)
	def get_IncrementalSince(self): # Long
		return self.get_body_params().get('IncrementalSince')

	def set_IncrementalSince(self, IncrementalSince):  # Long
		self.add_body_params('IncrementalSince', IncrementalSince)
	def get_Name(self): # String
		return self.get_body_params().get('Name')

	def set_Name(self, Name):  # String
		self.add_body_params('Name', Name)
	def get_Description(self): # String
		return self.get_body_params().get('Description')

	def set_Description(self, Description):  # String
		self.add_body_params('Description', Description)
	def get_ProjectId(self): # Long
		return self.get_body_params().get('ProjectId')

	def set_ProjectId(self, ProjectId):  # Long
		self.add_body_params('ProjectId', ProjectId)
